'---------------------------------------------------------------------
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
' THIS CODE AND INFORMATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY
' KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
' IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
' PARTICULAR PURPOSE.
'
'---------------------------------------------------------------------

Option Explicit On
Option Strict On

Imports System.ComponentModel
Imports System.ComponentModel.Design
Imports System.Collections.Generic
Imports System.Collections.ObjectModel
Imports System.Diagnostics
Imports System.Text
Imports System.Windows.Forms
Imports System.Windows.Forms.Design
Imports System.Windows.Forms.Design.Behavior

Imports DesignSurfaceExtenderLibrary.Extensions

''' <summary>
''' The <see cref="DesignSurfaceExtenderActionList"/> class provides the
''' basic <see cref="DesignerActionItem"/> entries for the <see cref="DesignSurfaceExtender"/>
''' component.
''' </summary>
''' <remarks>By default, the <see cref="DesignSurfaceExtender"/> component has
''' two <see cref="DesignerActionMethodItem"/> entries:
''' <list type="bullet">
''' <item>Enable All Extensions</item>
''' <item>Disable All Extensions</item>
''' </list>
''' The <see cref="DesignSurfaceExtenderDesigner"/> populates the action list
''' collection with action lists from all the available extensions. 
''' </remarks>
Friend Class DesignSurfaceExtenderActionList
    Inherits DesignerActionList

    Private extensionsValue As ReadOnlyCollection(Of DesignSurfaceExtension)

    Private ReadOnly enableAllPropertyName As String = "EnableAll"
    Private ReadOnly enableAllDisplayText As String = "Enable All Extensions"

    Private ReadOnly disableAllPropertyName As String = "DisableAll"
    Private ReadOnly disableAllDisplayText As String = "Disable All Extensions"

    ' This field backs the UiService property.
    Private _uiService As DesignerActionUIService

    ''' <summary>
    ''' The <see cref="DesignSurfaceExtenderActionList"/> constructor has
    ''' private access, to enforce the factory pattern. 
    ''' </summary>
    ''' <param name="component">The component attached to this action list.</param>
    Private Sub New(ByVal component As IComponent)
        MyBase.New(component)
    End Sub

    Public Shared Function Create( _
    ByVal component As IComponent, _
    ByVal extensions As ReadOnlyCollection(Of DesignSurfaceExtension)) _
    As DesignSurfaceExtenderActionList
        Dim actionList As DesignSurfaceExtenderActionList = New DesignSurfaceExtenderActionList(component)
        actionList.Extensions = extensions

        Return actionList
    End Function

    Public Overrides Function GetSortedActionItems() As DesignerActionItemCollection
        Dim items As DesignerActionItemCollection = _
            New DesignerActionItemCollection()

        items.Add(New DesignerActionMethodItem( _
            Me, _
            enableAllPropertyName, _
            enableAllDisplayText))

        items.Add(New DesignerActionMethodItem( _
            Me, _
            disableAllPropertyName, _
            disableAllDisplayText))

        Return items
    End Function

    Public Property Extensions() As ReadOnlyCollection(Of DesignSurfaceExtension)
        Get
            Return Me.extensionsValue
        End Get
        Set(ByVal value As ReadOnlyCollection(Of DesignSurfaceExtension))
            Me.extensionsValue = value
        End Set
    End Property

    Friend ReadOnly Property UiService() As DesignerActionUIService
        Get
            If Me._uiService Is Nothing Then
                Me._uiService = CType(GetService(GetType(DesignerActionUIService)), DesignerActionUIService)
            End If

            Return _uiService
        End Get
    End Property

    Friend Sub EnableAll()
        For i As Integer = 0 To Me.extensionsValue.Count - 1
            Me.extensionsValue(i).Enabled = True
        Next

        Me.uiService.Refresh(Me.Component)
    End Sub

    Friend Sub DisableAll()
        For i As Integer = 0 To Me.extensionsValue.Count - 1
            Me.extensionsValue(i).Enabled = False
        Next

        Me.uiService.Refresh(Me.Component)
    End Sub

End Class
